Description Format Value Constructor Fields Super class Methods See Also
Parameter definition for the Average Outcome Transportation (AOT).
R6Class object.
Param_base object
define_param(Param_AOT, observed_likelihood, intervention_list, ..., outcome_node)
observed_likelihoodA Likelihood corresponding to the observed likelihood
intervention_list_treatmentA list of objects inheriting from LF_base, representing the treatment intervention.
intervention_list_controlA list of objects inheriting from LF_base, representing the control intervention.
...Not currently used.
outcome_nodecharacter, the name of the node that should be treated as the outcome
cf_likelihood_onsitethe counterfactual likelihood for clinical trial
cf_likelihood_offsitethe counterfactual likelihood for real world
tmle3::Param_base -> Param_AOT
new()Param_AOT$new( observed_likelihood, onsite = 1, offsite = 0, fit_s_marginal = "empirical", ..., site_node = "S", outcome_node = "Y" )
clever_covariates()Param_AOT$clever_covariates(tmle_task = NULL, fold_number = "full")
estimates()Param_AOT$estimates(tmle_task = NULL, fold_number = "full")
clone()The objects of this class are cloneable with this method.
Param_AOT$clone(deep = FALSE)
deepWhether to make a deep clone.
Other Parameters:
Param_AET,
Param_SET,
Param_SOT
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.