Description Format Value Constructor Fields Super classes Methods See Also
Survival Outcome Transportation
Survival Outcome Transportation
R6Class object.
Param_base object
define_param(Param_survival, observed_likelihood, intervention_list, ..., outcome_node)
observed_likelihoodA Likelihood corresponding to the observed likelihood
intervention_listA list of objects inheriting from LF_base, representing the intervention.
...Not currently used.
outcome_nodecharacter, the name of the node that should be treated as the outcome
cf_likelihoodthe counterfactual likelihood for this treatment
intervention_listA list of objects inheriting from LF_base, representing the intervention
tmle3::Param_base -> tmle3trans::Param_AOT -> tmle3trans::Param_SOT -> Param_SET
new()Param_SET$new( observed_likelihood, intervention, onsite = 1, offsite = 0, target_times = NULL, fit_s_marginal = "empirical", ..., intervention_node = "A", outcome_node = "failed" )
clever_covariates_internal()Param_SET$clever_covariates_internal( tmle_task = NULL, fold_number = "full", subset_times = FALSE )
estimates()Param_SET$estimates(tmle_task = NULL, fold_number = "full")
clone()The objects of this class are cloneable with this method.
Param_SET$clone(deep = FALSE)
deepWhether to make a deep clone.
Other Parameters:
Param_AET,
Param_AOT,
Param_SOT
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.